@@ -18,7 +18,9 @@ if __name__ == "__main__":
         idem_dynes.append("acct")
 
     dyne_list = set(idem_dynes + list(ctx.short_dyne_list))
-    pop_create_core = ["seed", "tests", "docs"]
+    # FIXME generating tests is problematic for some reason
+    # pop_create_core = ["seed", "tests", "docs"]
+    pop_create_core = ["seed", "docs"]
     seed_ctx = NamespaceDict(vertical=True, dyne_list=dyne_list)
 
     if "cloud_spec" not in ctx:
