@@ -8,7 +8,7 @@ def __init__(hub):
 
     def _get_version_sub(ctx, *args, **kwargs):
         api_version = ctx.acct.get("api_version", "latest")
-        return hub.exec.vmc[api_version]
+        return hub.exec.{{cookiecutter.service_name}}
 
     # Get the version sub dynamically from the ctx variable/acct
     hub.pop.sub.dynamic(hub.exec.{{cookiecutter.service_name}}, _get_version_sub)
